==> org.eclipse.lsp4j.debug_0.20.0.v20230213-1727.jar: org/eclipse/lsp4j/debug/StepInTargetsArguments.java <==
/**
 * Copyright (c) 2017, 2020 Kichwa Coders Ltd. and others.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0,
 * or the Eclipse Distribution License v. 1.0 which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 * 
 * SPDX-License-Identifier: EPL-2.0 OR BSD-3-Clause
 */
package org.eclipse.lsp4j.debug;

import com.google.common.base.MoreObjects;

/**
 * Arguments for 'stepInTargets' request.
 */
@SuppressWarnings("all")
public class StepInTargetsArguments {
  /**
   * The stack frame for which to retrieve the possible step-in targets.
   */
  private int frameId;

  /**
   * The stack frame for which to retrieve the possible step-in targets.
   */
  public int getFrameId() {
    return this.frameId;
  }

  /**
   * The stack frame for which to retrieve the possible step-in targets.
   */
  public void setFrameId(final int frameId) {
    this.frameId = frameId;
  }

  @Override
  public String toString() {
    MoreObjects.ToStringHelper b = MoreObjects.toStringHelper(this);
    b.add("frameId", this.frameId);
    return b.toString();
  }

  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
      return true;
    if (obj == null)
      return false;
    if (getClass() != obj.getClass())
      return false;
    StepInTargetsArguments other = (StepInTargetsArguments) obj;
    if (other.frameId != this.frameId)
      return false;
    return true;
  }

  @Override
  public int hashCode() {
    return 31 * 1 + this.frameId;
  }
}

==> org.eclipse.lsp4j.debug_0.21.0.v20230517-2120.jar: org/eclipse/lsp4j/debug/StepInTargetsArguments.java <==
/**
 * Copyright (c) 2017, 2020 Kichwa Coders Ltd. and others.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0,
 * or the Eclipse Distribution License v. 1.0 which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 * 
 * SPDX-License-Identifier: EPL-2.0 OR BSD-3-Clause
 */
package org.eclipse.lsp4j.debug;

import org.eclipse.lsp4j.debug.util.ToStringBuilder;

/**
 * Arguments for 'stepInTargets' request.
 */
@SuppressWarnings("all")
public class StepInTargetsArguments {
  /**
   * The stack frame for which to retrieve the possible step-in targets.
   */
  private int frameId;

  /**
   * The stack frame for which to retrieve the possible step-in targets.
   */
  public int getFrameId() {
    return this.frameId;
  }

  /**
   * The stack frame for which to retrieve the possible step-in targets.
   */
  public void setFrameId(final int frameId) {
    this.frameId = frameId;
  }

  @Override
  public String toString() {
    ToStringBuilder b = new ToStringBuilder(this);
    b.add("frameId", this.frameId);
    return b.toString();
  }

  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
      return true;
    if (obj == null)
      return false;
    if (getClass() != obj.getClass())
      return false;
    StepInTargetsArguments other = (StepInTargetsArguments) obj;
    if (other.frameId != this.frameId)
      return false;
    return true;
  }

  @Override
  public int hashCode() {
    return 31 * 1 + this.frameId;
  }
}
